@@ -8,7 +8,7 @@ use Carp;
 
 use subs qw();
 
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 
 =encoding utf8
 
@@ -180,13 +180,14 @@ my %names = (
 	'High Sierra', 'Mojave', 'Catalina'],
 	'11' => [ 'Big Sur' ],
 	'12' => [ 'Monterey' ],
-	'13' => [ 'Mammoth' ],
+	'13' => [ 'Ventura' ],
 	 );
 
 my %release_dates = (
 	10 => [ ],
 	11 => [ ],
 	12 => [ ],
+	13 => [ ],
 	);
 
 sub default_major_version { '10' }
@@ -477,8 +478,6 @@ sub uname {
 
 =head1 TO DO
 
-* How does the API look if there is a Mac OS 11?
-
 * Specify a remote machine
 
 =head1 SEE ALSO
